@@ -6,4 +6,4 @@ import os, sys
 sys.path.append(os.path.dirname(os.path.realpath(__file__)))
 
 from _version import __version__
-from main import Titration
+from main import Titration, getTitrableSites
