@@ -97,6 +97,9 @@ def inputPDBCheck(filename, sites, clean_pdb):
                     and resnumb not in chains_res[chain]
                     and str(resnumb) in sites[chain]
                 ):
+                    if Config.pypka_params["ffinput"] == "CHARMM":
+                        if resname in ("HSD", "HSE", "HSP"):
+                            resname = "HIS"
                     chains_res[chain][resnumb] = resname
 
     # if filetype == 'pdb' and not clean_pdb:
@@ -182,13 +185,14 @@ def cleanPDB(molecules, chains_res, inputpqr, outputpqr, automatic_sites):
     # All HIS will become fully protonated
     os.system(
         "python2 {0} {1} {2} --ff {3} --ffout {4} "
-        "--drop-water -v --chain > {5} 2>&1 ".format(
+        "--drop-water -v --chain {6} > {5} 2>&1 ".format(
             Config.pypka_params["pdb2pqr"],
             Config.pypka_params["pdb2pqr_inputfile"],
             inputpqr,
             Config.pypka_params["ffinput"],
             Config.pypka_params["ff_family"],
             logfile,
+            "" if Config.pypka_params["pdb2pqr_h_opt"] else "--noopt",
         )
     )
 
@@ -285,9 +289,18 @@ def cleanPDB(molecules, chains_res, inputpqr, outputpqr, automatic_sites):
                     )
                     resnumb_max = resnumb
 
+                    # if resname == "CY0":
+                    #    resname = "CYS"
+                    #    if aname == "HG1":
+                    #        continue
+
                     if resnumb in (NTR_numb, CTR_numb):
                         termini_trigger = True
 
+                if resname == "CYS":
+                    change_atoms = {"1CB": "CB", "1SG": "SG"}
+                    if aname in change_atoms.keys():
+                        aname = change_atoms[aname]
                 if (
                     aname in ("O1", "O2", "OT1", "OT2", "H1", "H2", "H3")
                     and not termini_trigger
@@ -528,6 +541,10 @@ def remove_membrane_n_rna(pdbfile, outfile):
                 if aname[0] == "H" and Config.pypka_params["remove_hs"]:
                     continue
 
+                if Config.pypka_params["ffinput"] == "CHARMM":
+                    if resname in ("HSD", "HSE"):
+                        resname = "HSP"
+
                 if resname not in to_remove:
                     if resname in PDB_RNA_RESIDUES:
                         resname = PDB_RNA_RESIDUES[resname]
@@ -629,7 +646,7 @@ def add_non_protein(pdbfile_origin, add_to_pdb, keep_membrane=False, keep_ions=F
                     if resname in LIPID_RESIDUES:
                         last_anumb += 1
                         new_file_body += new_pdb_line(
-                            last_anumb, aname, resname, resnumb, x, y, z, chain=chain
+                            last_anumb, aname, resname, resnumb, x, y, z, chain=" "
                         )
 
                     if resname in list(Config.pypka_params.LIPIDS.values()):
@@ -647,7 +664,7 @@ def add_non_protein(pdbfile_origin, add_to_pdb, keep_membrane=False, keep_ions=F
                                 x,
                                 y,
                                 z,
-                                chain=chain,
+                                chain=" ",
                             )
                 if keep_ions and aname in IONS and resname == aname:
                     last_anumb += 1
