@@ -228,7 +228,7 @@ class PypKaConfig(ParametersDict):
 
         # Paths
         self.file_dir = os.path.dirname(os.path.abspath(__file__))
-        self.script_dir = os.path.dirname(__file__)
+        self.ffs_dir = os.path.dirname(__file__)
 
         # PDB2PQR
         self.pdb2pqr = "{0}/clean/pdb2pqr/pdb2pqr.py".format(self.file_dir)
@@ -259,6 +259,7 @@ class PypKaConfig(ParametersDict):
         self.f_siz = None
         self.ffID = "G54A7"
         self.ff_family = "GROMOS"
+        self.sts = "sts"
         self.NTR_atoms = None
         self.CTR_atoms = None
         self.LIPIDS = {}
@@ -266,6 +267,7 @@ class PypKaConfig(ParametersDict):
         # Preprocessing parameters
         self.ffinput = "GROMOS"
         self.clean_pdb = True
+        self.pdb2pqr_h_opt = True
         self.remove_hs = True
         self.keep_ions = False
         self.ser_thr_titration = True
@@ -299,6 +301,7 @@ class PypKaConfig(ParametersDict):
             "cutoff": float,
             "slice": float,
             "clean_pdb": bool,
+            "pdb2pqr_h_opt": bool,
             "remove_hs": bool,
             "keep_ions": bool,
             "ser_thr_titration": bool,
@@ -307,6 +310,8 @@ class PypKaConfig(ParametersDict):
             "box": list,
             "CpHMD_mode": bool,
             "save_pdb": str,
+            "ffs_dir": str,
+            "sts": str,
         }
 
     def set_structure_extension(self):
@@ -340,7 +345,7 @@ class PypKaConfig(ParametersDict):
             self["ncpus"] = 1
 
     def set_radii_charges_paths(self):
-        file_path = os.path.join(self["script_dir"], self["ffID"])
+        file_path = os.path.join(self["ffs_dir"], self["ffID"])
         if not self["f_crg"]:
             self["f_crg"] = "{}/DataBaseT.crg".format(file_path)
         if not self["f_siz"]:
@@ -349,6 +354,7 @@ class PypKaConfig(ParametersDict):
         ffID = Config.pypka_params["ffID"].lower()
         if "charmm36m" in ffID:
             self["ff_family"] = "CHARMM"
+            self["ffinput"] = "CHARMM"
         elif "g54a7" in ffID:
             self["ff_family"] = "GROMOS"
         else:
@@ -394,17 +400,17 @@ class PypKaConfig(ParametersDict):
             self.log.raise_input_param_error("structure_output", message, "")
 
     def readTermini(self):
-        script_dir = self["script_dir"]
-        ffID = self["ffID"]
+        self.sts_path = "{0}/{1}/{2}/".format(self.ffs_dir, self.ffID, self.sts)
+
         NTR_atoms = []
-        ntr_fname = "{}/{}/sts/NTRtau1.st".format(script_dir, ffID)
+        ntr_fname = "{}/NTRtau1.st".format(self.sts_path)
         with open(ntr_fname) as f:
             for line in f:
                 parts = line.split()
                 if len(parts) > 1:
                     NTR_atoms.append(parts[1].strip())
         CTR_atoms = []
-        ctr_fname = "{}/{}/sts/CTRtau1.st".format(script_dir, ffID)
+        ctr_fname = "{}/CTRtau1.st".format(self.sts_path)
         with open(ctr_fname) as f:
             for line in f:
                 parts = line.split()
