@@ -18,12 +18,14 @@ class Log:
         if stdout:
             print(info)
 
-    def raise_required_param_error(self, parameter):
+    @staticmethod
+    def raise_required_param_error(parameter):
         raise IOError(
             'Required input parameter "{0}" ' "is not defined.".format(parameter)
         )
 
-    def raise_input_param_error(self, parameter, complaint, explanation):
+    @staticmethod
+    def raise_input_param_error(parameter, complaint, explanation):
         raise ValueError(
             'Input parameter "{0}" is not {1}\n '
             "{2}".format(parameter, complaint, explanation)
@@ -34,36 +36,6 @@ class Log:
         self.report2log(warning, stdout=stdout)
 
 
-def redirectOutput(mode, outputname):
-    if mode == "start":
-        config.stdout = os.dup(sys.stdout.fileno())
-        config.stdout_file = open(outputname, "w")
-        os.dup2(config.stdout_file.fileno(), sys.stdout.fileno())
-    elif mode == "stop":
-        if not config.stdout:
-            raise Exception(
-                "Output redirection has not been started, " "thus it can not be ended."
-            )
-        sys.stdout.flush()
-        os.dup2(config.stdout, sys.stdout.fileno())
-        config.stdout_file.close()
-
-
-def redirectErr(mode, outputname):
-    if mode == "start":
-        config.stderr = os.dup(sys.stderr.fileno())
-        config.stderr_file = open(outputname, "w")
-        os.dup2(config.stderr_file.fileno(), sys.stderr.fileno())
-    elif mode == "stop":
-        if not config.stderr:
-            raise Exception(
-                "Error redirection has not been started, " "thus it can not be ended."
-            )
-        sys.stderr.flush()
-        os.dup2(config.stderr, sys.stderr.fileno())
-        config.stderr_file.close()
-
-
 def checkDelPhiErrors(filename, mode=None):
     exceptions = []
     if mode == "readFiles":
